@@ -51,6 +51,8 @@ static char *state_title[] = {
 	NULL
 };
 
+#define d(x)
+
 void
 druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel)
 {
@@ -283,7 +285,7 @@ intro_page_ok (void)
 		    druid_data.submit_type == SUBMIT_REPORT) {
 			GtkWidget *d;
 			char *m;
-			m = g_strdup_printf (_("`%s' doesn't seem to exist.\n\n"
+			m = g_strdup_printf (_("'%s' doesn't seem to exist.\n\n"
 					       "You won't be able to actually "
 					       "submit a bug report, but you will\n"
 					       "be able to save it to a file.\n\n"
@@ -314,7 +316,7 @@ text_is_sensical (const gchar *text, int sensitivity)
 		if (!chars[(guchar)*text])
 			chars[(guchar)*text] = ++uniq;
 	
-	g_message ("%d", uniq);
+	d(g_message ("%d", uniq));
 
 	return chars[' '] && uniq >= sensitivity;
  }
@@ -339,7 +341,7 @@ desc_page_ok (void)
 		}
 
 		mime_type = gnome_mime_type_of_file (s);
-		g_message (_("File is of type: %s"), mime_type);
+		d(g_message (_("File is of type: %s"), mime_type));
 		
 		if (!mime_type || strncmp ("text/", mime_type, 5)) {
 			char *msg = g_strdup_printf (_("'%s' does not look like a text file."), s);
@@ -377,6 +379,13 @@ submit_ok (void)
 	GtkWidget *w;
 	FILE *fp;
 
+	if (druid_data.submit_type != SUBMIT_FILE) {
+		w = gnome_question_dialog (_("Submit this bug report now?"),
+					   NULL, NULL);
+		if (gnome_dialog_run_and_close (GNOME_DIALOG (w)))
+			return FALSE;
+	}
+
 	w = GET_WIDGET ( (druid_data.submit_type == SUBMIT_TO_SELF)
 			 ? "email-email-entry" : "email-to-entry");
 	to = gtk_editable_get_chars (GTK_EDITABLE (w), 0, -1);
@@ -397,7 +406,7 @@ submit_ok (void)
 		s = gtk_editable_get_chars (GTK_EDITABLE (w), 0, -1);
 		command = g_strdup_printf ("%s -i -t", s);
 
-		g_message (_("about to run '%s'"), command);
+		d(g_message (_("about to run '%s'"), command));
 		fp =  popen (command, "w");
 		g_free (command);
 		if (!fp) {
@@ -411,6 +420,21 @@ submit_ok (void)
 		g_free (s);
 	}
 
+	{
+		char *name, *from;
+		
+		w = GET_WIDGET ("email-name-entry");
+		name = gtk_editable_get_chars (GTK_EDITABLE (w), 0, -1);
+
+
+		w = GET_WIDGET ("email-email-entry");
+		from = gtk_editable_get_chars (GTK_EDITABLE (w), 0, -1);
+
+		fprintf (fp, "From: %s <%s>\n", name, from);
+		g_free (from);
+		g_free (name);
+	}
+
 	fprintf (fp, "To: %s\n", to);
 
 	if (druid_data.submit_type == SUBMIT_REPORT &&
@@ -438,7 +462,7 @@ submit_ok (void)
 		s = g_strdup_printf (_("Your bug report was saved in '%s'"), file);
 	} else {
 		pclose (fp);
-		s = g_strdup_printf (_("Your bug report has been submitted to:\n\n        <%s>"), to);
+		s = g_strdup_printf (_("Your bug report has been submitted to:\n\n        <%s>\n\nThanks!"), to);
 	}
 	g_free (to);
 
@@ -527,5 +551,6 @@ on_druid_cancel_clicked (GtkWidget *w, gpointer data)
 	if (gnome_dialog_run_and_close (GNOME_DIALOG (d)))
 		return;
 
+	save_config ();
 	gtk_main_quit ();
 }
